"""
Program analyzes word frequency in a file.

User specifies the name of the input file.
User chooses the number of most frequent words to report.
Program prints report of most frequent words.
"""


def main():
    print('This program analyzes word frequency in a file')
    print('and prints a report on the n most frequent words.\n')

    text = get_text()
    prepared_text = prepare_text(text)
    words = prepared_text.split()
    counts = count_words(words)
    n = int(input('Output analysis of how many words? '))
    print_report(counts, n)


def get_text():
    infile_name = input('File to analyze: ')
    infile = open(infile_name, 'r', encoding='utf-8')
    text = infile.read()
    infile.close()
    return text


def prepare_text(text):
    text = text.lower()
    for ch in '!"\'  # $%&()*+,-./:;<=>?@[\\]^_`{|}~':
        text = text.replace(ch, ' ')
    return text


def count_words(words):
    counts = {}
    for word in words:
        counts[word] = counts.get(word, 0) + 1
    return counts


def print_report(counts, n):
    items = list(counts.items())
    items.sort()
    items.sort(key=by_frequency, reverse=True)
    for i in range(n):
        word, count = items[i]
        print(f'{word:<15}{count:>5}')


def by_frequency(pair):
    return pair[1]


if __name__ == '__main__':
    main()
